quantizationtools.QTargetBeat
=============================

.. abjad-lineage:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat

.. autoclass:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.beatspan
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.distances
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.duration_in_ms
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.offset_in_ms
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.q_events
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.q_grid
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.q_grids
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.search_tree
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.tempo
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__call__
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__eq__
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__format__
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__hash__
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__ne__
      ~abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.beatspan
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.distances
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.duration_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.offset_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.q_events
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.q_grid
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.q_grids
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.search_tree
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.tempo
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__hash__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QTargetBeat.QTargetBeat.__repr__
   :noindex:
